@@ -82,16 +82,17 @@ def list_jobs(
             "reverse": True,
         },
     )
+    resp.raise_for_status()
     if ctx.obj.output == "json":
         echo(dumps(resp.json()))
         return
-    node_heartbeats = {r["node_id"]: None for r in resp.json()["jobs"]}
+    node_heartbeats = {r["node_id"]: None for r in resp.json()}
     for node_id in node_heartbeats.keys():
         url = ctx.obj.session.knode_url + f"/nodes/{node_id}"
         last_heartbeat = None
         try:
             node_resp = ctx.obj.session.get(url)
-            last_heartbeat = node_resp.json()["last_modified"]
+            last_heartbeat = node_resp.json()["modified_date"]
         except Exception:
             pass
         node_heartbeats[node_id] = last_heartbeat
@@ -110,7 +111,7 @@ def list_jobs(
         "Result",
         "Heartbeat",
     ]
-    for job in resp.json()["jobs"]:
+    for job in resp.json():
         args = job["args"]
         regions = ""
         for a in args:
@@ -136,8 +137,8 @@ def list_jobs(
                 regions,
                 job["node_id"],
                 address,
-                fmt_date(job["created"]),
-                fmt_date(job["last_modified"]),
+                fmt_date(job["create_date"]),
+                fmt_date(job["modified_date"]),
                 job.get("result"),
                 heartbeat_txt,
             ]
@@ -189,7 +190,7 @@ def view_job(ctx: Context, job_id: str = Argument(..., help="Job ID to view")):
     for k in [
         "node_id",
         "status",
-        "last_modified",
+        "modified_date",
         "registered",
         "instance_type",
         "availability_zone",
@@ -226,7 +227,7 @@ def shutdown_job(
             abort=True,
         )
 
-    resp = ctx.obj.session.patch(url, json={"shutdown": True})
+    resp = ctx.obj.session.patch(url, json={"status": "shutdown"})
 
     if ctx.obj.output == "json":
         output = {"job": job_id, "tenant": tenant, "success": True, "command": "shutdown"}
@@ -294,7 +295,7 @@ def shutdown_all(
         url,
         params=params,
     )
-    jobs = resp.json()["jobs"]
+    jobs = resp.json()
     cnt = len(jobs)
     for job in jobs:
         job_url = url + "/" + job["job_id"]
@@ -307,7 +308,7 @@ def shutdown_all(
                 url,
                 params=params,
             )
-            n = len(resp.json()["jobs"])
+            n = len(resp.json())
             if n <= 0:
                 break
             out(f"Waiting for {n} jobs to stop")
@@ -353,11 +354,11 @@ def delete_all(
         tenant = None
     url = ctx.obj.session.knode_url + f"/jobs"
     resp = ctx.obj.session.get(url, params={"tenant": tenant, "start": 0, "end": 100, "status": ""})
-    for job in resp.json()["jobs"]:
-        job_url = url + "/" + job["job_id"]
+    for job in resp.json():
+        job_url = url + "/" + str(job["job_id"])
         _ = ctx.obj.session.delete(job_url)
 
-    cnt = len(resp.json()["jobs"])
+    cnt = len(resp.json())
     if ctx.obj.is_all:
         success(
             f"{cnt} jobs have been deleted. All jobs on server have been removed.",
@@ -378,7 +379,7 @@ def cleanup(ctx: Context):
         jobs_url, params={"tenant": tenant, "start": 0, "end": 100, "status": "running,pending,processing"}
     )
     n = 0
-    for job in resp.json()["jobs"]:
+    for job in resp.json():
         node_id = job["node_id"]
         url = ctx.obj.session.knode_url + f"/nodes/{node_id}"
         try:
@@ -395,6 +396,44 @@ def cleanup(ctx: Context):
     else:
         success(f"No orphaned jobs to clean up", bold=True)
 
+@app.command("duplicate")
+@check_tenant
+def duplicate_job(ctx: Context, job_id: str):
+    for j in job_id.split(","):
+        j = j.strip()
+        tenant = ctx.obj.tenant
+        url = ctx.obj.session.knode_url + f"/jobs/{j}"
+        resp = ctx.obj.session.get(url)
+        resp.raise_for_status()
+        job =  resp.json()
+        version = job["version"]
+        s3_path = job["s3_path"]
+        cpu = job["resources"].get("cpu", 0)
+        mem = job["resources"].get("ram", "0 GB")
+        map_name = job["map_name"]
+        executable = job["executable"]
+        args = job["args"]
+        data = {
+            "tenant": tenant,
+            "tenant_only": True,
+            "version": version or "none",
+            "map_name": map_name,
+            "resources": {"cpu": cpu, "ram": mem},
+            "executable": executable,
+            "s3_path": s3_path,
+            "args": args,
+        }
+        url = ctx.obj.session.knode_url + f"/jobs"
+        try:
+            resp = ctx.obj.session.post(url, json=data)
+        except ServerError as ex:
+            abort(ex)
+        content = resp.json()
+        if ctx.obj.output == "json":
+            print(json.dumps(content, indent=2))
+        else:
+            new_job_id = content["job_id"]
+            secho(f"Job {new_job_id} created from job {j}", bold=True)
 
 @app.command("create")
 @check_tenant
@@ -425,11 +464,12 @@ def create_job(
         "-y",
         is_flag=True,
         help="Create the requested jobs without a prompt",
-    ),
+    )
 ):
     """Create a new job. Deploy the most recent server build by default"""
     tenant = ctx.obj.tenant
     builds_path = ctx.obj.session.profile.builds_path
+
     if version and not builds_path:
         abort("You must set a build path with 'kamo builds path' to deploy a versioned build")
 
