@@ -105,11 +105,11 @@ def edit_profile(ctx: Context):
 @app.command("add")
 def add_profile(
     ctx: Context,
-    profile: str = Option(..., "-p", "--domain", prompt="What would you like to call this profile?"),
+    profile: str = Option(..., "-p", "--profile", prompt="What would you like to call this profile?"),
     domain: str = Option(..., "-d", "--domain", prompt="Domain name of the service (e.g. kamo.io)"),
-    # tenant: str = Option(..., "-t", "--tenant", prompt="Default tenant (e.g. staging)"),
     api_key: str = Option(..., "-k", "--api-key", prompt="API Key"),
     replace: bool = Option(False, "-r", "--replace", is_flag=True, help="Replace an existing profile"),
+    tenant: str = Option(None, "-t", "--tenant", help="Default tenant (e.g. staging)"),
     skip_auth: str = Option(
         False, "-s", "--skip-auth", is_flag=True, help="Skip authentication (for local development)"
     ),
@@ -143,12 +143,13 @@ def add_profile(
                 return
 
     try:
-        create_profile(profile, api_key=api_key, domain=domain, skip_auth=skip_auth)
+        create_profile(profile, api_key=api_key, domain=domain, skip_auth=skip_auth, tenant=tenant)
     except InvalidProfile as ex:
         abort(ex)
     set_default_profile(profile)
     echo("Profile has been added and is now active. If you want to edit it please run: kamo profile edit.")
-    secho("Please select a tenant with 'kamo tenants list' / 'kamo tenants set'")
+    if not tenant:
+        secho("Please select a tenant with 'kamo tenants list' / 'kamo tenants set'")
 
 
 @app.command("delete")
